@@ -5,11 +5,12 @@ vtelem - An interface for setting up and tearing down outgoing udp streams.
 # built-in
 import logging
 import socket
-from typing import Dict, List, Tuple, Any
+from typing import Any, Dict, List, Tuple, cast
 
 # internal
-from vtelem.mtu import create_udp_socket, discover_mtu, Host
+from vtelem.mtu import Host, create_udp_socket, discover_mtu
 from vtelem.stream.writer import StreamWriter
+
 from .time_entity import LockEntity
 
 LOG = logging.getLogger(__name__)
@@ -70,7 +71,7 @@ class UdpClientManager(LockEntity):
         sock = create_udp_socket(host)
         mtu = discover_mtu(sock)
         mtu -= 60 + 8  # subtract ip and udp header space
-        sock_file = sock.makefile("wb")
+        sock_file = cast(socket.socket, sock).makefile("wb")
         sock_file.flush()
 
         with self.lock:
