@@ -9,7 +9,7 @@ from typing import List, Tuple
 # internal
 from vtelem.daemon.command_queue import CommandQueueDaemon
 from vtelem.daemon.manager import DaemonManager
-from vtelem.enums.daemon import is_operation, DaemonOperation, operation_str
+from vtelem.enums.daemon import DaemonOperation, is_operation, operation_str
 from vtelem.types.command_queue_daemon import ResultCbType
 
 
